/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.common.policies.data;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.SneakyThrows;
import org.apache.pulsar.common.policies.data.impl.DispatchRateImpl;

/**
 * Subscription policies.
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class SubscriptionPolicies implements Cloneable {
    private DispatchRateImpl dispatchRate;

    /**
     * Check if this SubscriptionPolicies is empty. Empty SubscriptionPolicies can be auto removed from TopicPolicies.
     * @return true if this SubscriptionPolicies is empty.
     */
    public boolean checkEmpty() {
        return dispatchRate == null;
    }

    @SneakyThrows
    @Override
    protected SubscriptionPolicies clone() {
        SubscriptionPolicies cloned = SubscriptionPolicies.class.cast(super.clone());
        cloned.dispatchRate = dispatchRate != null ? dispatchRate.clone() : null;
        return cloned;
    }
}
